@@ -20,6 +20,9 @@ SnapdGetFind *_snapd_get_find_new                    (GCancellable        *cance
                                                       GAsyncReadyCallback  callback,
                                                       gpointer             user_data);
 
+void          _snapd_get_find_set_common_id          (SnapdGetFind        *request,
+                                                      const gchar         *common_id);
+
 void          _snapd_get_find_set_query              (SnapdGetFind        *request,
                                                       const gchar         *query);
 
@@ -32,7 +35,7 @@ void          _snapd_get_find_set_select             (SnapdGetFind        *reque
 void          _snapd_get_find_set_section            (SnapdGetFind        *request,
                                                       const gchar         *section);
 
-void          _snapd_get_find_set_scope             (SnapdGetFind        *request,
+void          _snapd_get_find_set_scope              (SnapdGetFind        *request,
                                                       const gchar         *scope);
 
 GPtrArray    *_snapd_get_find_get_snaps              (SnapdGetFind        *request);
