@@ -139,6 +139,34 @@ snapd_client_login2_sync (SnapdClient *self,
     return snapd_client_login2_finish (self, data.result, error);
 }
 
+/**
+ * snapd_client_logout_sync:
+ * @client: a #SnapdClient.
+ * @id: login ID to use.
+ * @cancellable: (allow-none): a #GCancellable or %NULL.
+ * @error: (allow-none): #GError location to store the error occurring, or %NULL to ignore.
+ *
+ * Log out from snapd.
+ *
+ * Returns: %TRUE on success or %FALSE on error.
+ *
+ * Since: 1.55
+ */
+gboolean
+snapd_client_logout_sync (SnapdClient *self,
+                          gint64 id,
+                          GCancellable *cancellable, GError **error)
+{
+    g_return_val_if_fail (SNAPD_IS_CLIENT (self), FALSE);
+
+    g_auto(SyncData) data = { 0 };
+    start_sync (&data);
+    snapd_client_logout_async (self, id, cancellable, sync_cb, &data);
+    end_sync (&data);
+
+    return snapd_client_logout_finish (self, data.result, error);
+}
+
 /**
  * snapd_client_get_changes_sync:
  * @client: a #SnapdClient.
@@ -1599,3 +1627,34 @@ snapd_client_run_snapctl_sync (SnapdClient *self,
     end_sync (&data);
     return snapd_client_run_snapctl_finish (self, data.result, stdout_output, stderr_output, error);
 }
+
+/**
+ * snapd_client_download_sync:
+ * @client: a #SnapdClient.
+ * @name: name of snap to download.
+ * @channel: (allow-none): channel to download from.
+ * @revision: (allow-none): revision to download.
+ * @cancellable: (allow-none): a #GCancellable or %NULL.
+ * @error: (allow-none): #GError location to store the error occurring, or %NULL
+ *     to ignore.
+ *
+ * Download the given snap.
+ *
+ * Returns: the snap contents or %NULL on error.
+ *
+ * Since: 1.54
+ */
+GBytes *
+snapd_client_download_sync (SnapdClient *self,
+                            const gchar *name, const gchar *channel, const gchar *revision,
+                            GCancellable *cancellable, GError **error)
+{
+    g_return_val_if_fail (SNAPD_IS_CLIENT (self), NULL);
+    g_return_val_if_fail (name != NULL, NULL);
+
+    g_auto(SyncData) data = { 0 };
+    start_sync (&data);
+    snapd_client_download_async (self, name, channel, revision, cancellable, sync_cb, &data);
+    end_sync (&data);
+    return snapd_client_download_finish (self, data.result, error);
+}
